//+------------------------------------------------------------------+
//|       Sell Script for multiple contracts / orders with SL and TP |
//|                                                                  |
//| Used it to trade Woodie CCI Patterns                             |
//|                                                                  |
//| For example:                                                     |
//| - sell 2 contracts with one click (but each one seperately)      |
//| - this two orders get different magic numbers                    |
//|   (1st 1111, 2nd 2222, ....) so you can handle this contracts    |
//|   with an other order management EA differently                  |
//| - I used "Swiss Army EA v1.51" to handle trade management        |
//|   automaticly in woodie like (set stop loss on both contracts,   |
//|   first contract get a target, second one not but a breakeven    |
//|   stop after hit target one and so on....                        |
//|   You have to put Swiss Army EA in two different charts and      |
//|   set first one to magic number 1111, second EA to 2222,...      |
//|   and do your stop/target stuff differently!                     |
//|                                                                  |
//| Get "Swiss Army EA v1.51" here:                                  | 
//| http://www.forex-tsd.com/expert-advisors-metatrader-4/           |
//| 7552-swiss-army-ea-automatic-order-management.html               |
//|                                                                  |
//|                                          Copyright  2009, Heart |
//+------------------------------------------------------------------+
#property copyright "Copyright  2009, Heart"
#property link      "heart1010@gmail.com"


#property show_inputs

extern int    NumberOfOrders = 2;
extern double Lots = 0.06;
extern string Note1="---------------------------------------";


extern double StopLoss = 0; // (in Pips)
extern double TakeProfit = 0; // (in Pips)
extern string Note2="---------------------------------------";

extern bool   UseActualSlTp = false;
extern double StopLossPrice = 0.0000;
extern double TakeProfitPrice = 0.0000;

extern string Note3="0 in Entry field means Market Order Sell";
extern double Entry = 0.0000;

extern bool   MicroOrdersAllowed = true;
extern bool   MiniOrdersAllowed = true;

extern bool   UseMoneyMgmt = false;
extern double RiskPercent = 2;
extern int    MagicNumber = 1111;

extern string Comments = "WCCI Pattern Trade (Sell)";

//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
  { 
  double Risk = RiskPercent / 100;
  int OrdersizeAllowed = 0;
  int ticket;
  double SLB = 0;
  double TPB = 0;
  
  int Mode = OP_SELLSTOP;
  if (Bid < Entry && Entry > 0) Mode = OP_SELLLIMIT; 
  if (Entry == 0)  {
         Entry = Bid; 
         Mode = OP_SELL;
  } else {
         SLB = Entry+StopLoss*Point;
         TPB = Entry-TakeProfit*Point;
  }
  
  if (UseActualSlTp)  {
      StopLoss = (StopLossPrice-Entry)/Point;
      SLB = StopLossPrice;
      TPB = TakeProfitPrice;    
      }
      
  if (MiniOrdersAllowed) OrdersizeAllowed=1;
  if (MicroOrdersAllowed) OrdersizeAllowed=2;        
  
  if (UseMoneyMgmt)  
      Lots = NormalizeDouble( AccountBalance()*Risk/StopLoss/(MarketInfo(Symbol(), MODE_TICKVALUE)),OrdersizeAllowed);       

  if ((Lots < 0.01&&MicroOrdersAllowed) || (Lots < 0.1&&MiniOrdersAllowed&&MicroOrdersAllowed==false))
      {
         Print("YOUR LOTS SIZE IS TOO SMALL TO PLACE!");
      } 

  if(Lots > 0)
  for (int i=0;i<NumberOfOrders;i++)
      {
       //ticket=OrderSend(Symbol(),OP_BUY,1,Ask,3,Ask-25*Point,Ask+25*Point,"My order #2",16384,0,Green);
       ticket=OrderSend(Symbol(),Mode, Lots, Entry, 2,SLB , TPB, Comments, MagicNumber, NULL, Red);
       if(ticket<0)
       {
        Print("OrderSend failed with error #",GetLastError());
        return(0);
       }

         Print("sold with magic number: ",MagicNumber);
         MagicNumber = MagicNumber+1111;
      }

           
   return(0);
  }
//+------------------------------------------------------------------+